@@ -1,3 +1,5 @@
+import inspect
+
 from pydiator_core.interfaces import BaseRequest, BasePipeline
 from pydiator_core.mediatr_container import BaseMediatrContainer
 
@@ -16,4 +18,8 @@ class DefaultPipeline(BasePipeline):
         if not callable(handle_func):
             raise Exception("handle_function_has_not_found_in_handler")
 
+        is_async = inspect.iscoroutinefunction(handler.handle)
+        if not is_async:
+            return handler.handle(req)
+
         return await handler.handle(req)
